acyclic.utils.log


fnameclj

(fname f)

Extract the qualified name of a clojure function as a string.

Extract the qualified name of a clojure function as a string.
raw docstring

iidclj

(iid & s)

iidaclj


log-atomclj


OPTPATclj


redis-atomclj


set-logging!clj

(set-logging! log)

stack-traceclj

(stack-trace e)

STR->OPTclj


with-accrued-logclj

(with-accrued-log m)

cljdoc builds & hosts documentation for Clojure/Script libraries